SEAPY ROMS Package Documentation
================================

:mod:`seapy.roms` -- Working with ROMS fields and observations
**************************************************************

.. automodule:: seapy.roms.__init__
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: seapy.roms.lib
   :members:
   :undoc-members:
   :show-inheritance:



:mod:`analysis` -- Performing analysis on output fields
-------------------------------------------------------
.. automodule:: seapy.roms.analysis
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`boundary` -- Generating Boundary Conditions
-------------------------------------------------
.. automodule:: seapy.roms.boundary
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`clim` -- Working with Climatology Conditions
--------------------------------------------------
.. automodule:: seapy.roms.clim
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`ezgrid` -- Generating grids for ROMS
--------------------------------------------------
.. automodule:: seapy.roms.ezgrid
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`forcing` -- Working with Atmospheric Conditions
-----------------------------------------------------
.. automodule:: seapy.roms.forcing
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`initial` -- Generating Initial Conditions
-----------------------------------------------
.. automodule:: seapy.roms.initial
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`interp` -- Converting between grids
-----------------------------------------
.. automodule:: seapy.roms.interp
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`ncgen` -- Generate ROMS files
-----------------------------------
.. automodule:: seapy.roms.ncgen
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`obs` -- Store ROMS observations
-------------------------------------
.. automodule:: seapy.roms.obs
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`obsgen` -- Generate ROMS observations from raw data
---------------------------------------------------------
.. automodule:: seapy.roms.obsgen
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`tide` -- Work with ROMS tides
-----------------------------------
.. automodule:: seapy.roms.tide
   :members:
   :undoc-members:
   :show-inheritance:




